@@ -3,9 +3,9 @@ mod data;
 pub mod disc;
 pub mod game;
 pub mod position;
-pub mod solvers;
+pub mod strategies;
 
 pub use board::Board;
 pub use disc::Disc;
-pub use game::{Game, Play, ValidMove};
+pub use game::{Game, Play};
 pub use position::Position;
